@@ -26,6 +26,37 @@ UNICODE_CATEGORIES: Categories = {
     "Mn": None,
     "Mc": WS,
     "Me": None,
+    "No": None,
+    "Zs": WS,
+    "Zl": WS,
+    "Zp": WS,
+    "Pc": WS,  # TODO: figure out if this wants to be None
+    "Pd": WS,
+    "Ps": WS,
+    "Pe": WS,
+    "Pi": WS,
+    "Pf": WS,
+    "Po": WS,
+    "Sm": WS,
+    "Sc": None,
+    "Sk": None,
+    "So": WS,
+    "Zs": WS,
+    "Zl": WS,
+    "Zp": WS,
+}
+
+SLUG_CATEGORIES: Categories = {
+    "Cc": None,
+    "Cf": None,
+    "Cs": None,
+    "Co": None,
+    "Cn": None,
+    # "Lm": None,
+    # "Mn": None,
+    "Mc": WS,
+    "Me": None,
+    "No": None,
     "Zs": WS,
     "Zl": WS,
     "Zp": WS,
@@ -36,9 +67,14 @@ UNICODE_CATEGORIES: Categories = {
     "Pi": WS,
     "Pf": WS,
     "Po": WS,
+    "Sm": WS,
     "Sc": None,
     "Sk": None,
-    "So": None,
+    "So": WS,
+    "Zs": WS,
+    "Zl": WS,
+    "Zp": WS,
 }
 
+
 CONTROL_CODES: Categories = {"Cc": WS, "Cf": WS, "Cs": WS, "Co": WS, "Cn": WS}
